# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.taxonomy import topic_pb2 as eolymp_dot_taxonomy_dot_topic__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/taxonomy/topic_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/taxonomy/topic.proto\x1a!eolymp/wellknown/expression.proto\"9\n\x10\x43reateTopicInput\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"%\n\x11\x43reateTopicOutput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\"$\n\x10\x44\x65leteTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteTopicOutput\"\xba\x01\n\x10UpdateTopicInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.taxonomy.UpdateTopicInput.Patch\x12\x10\n\x08topic_id\x18\x02 \x01(\t\x12%\n\x05topic\x18\x03 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"5\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0b\n\x07SUMMARY\x10\x02\x12\x0c\n\x08KEYWORDS\x10\x03\"\x13\n\x11UpdateTopicOutput\"6\n\x12\x44\x65scribeTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x64 \x01(\t\"<\n\x13\x44\x65scribeTopicOutput\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"\xf0\x01\n\x0fListTopicsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.taxonomy.ListTopicsInput.Filter\x12\x0e\n\x06locale\x18\x64 \x01(\t\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListTopicsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.taxonomy.Topic\"p\n\x13TranslateTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x37\n\x0btranslation\x18\x03 \x01(\x0b\x32\".eolymp.taxonomy.Topic.Translation\"\x16\n\x14TranslateTopicOutput\":\n\x16\x44\x65leteTranslationInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"\xc3\x01\n\x15ListTranslationsInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.taxonomy.ListTranslationsInput.Filter\x1a:\n\x06\x46ilter\x12\x30\n\x06locale\x18\x01 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Z\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".eolymp.taxonomy.Topic.Translation2\xcb\n\n\x0cTopicService\x12\x90\x01\n\x0b\x43reateTopic\x12!.eolymp.taxonomy.CreateTopicInput\x1a\".eolymp.taxonomy.CreateTopicOutput\":\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\t\"\x07/topics\x12\x9b\x01\n\x0b\x44\x65leteTopic\x12!.eolymp.taxonomy.DeleteTopicInput\x1a\".eolymp.taxonomy.DeleteTopicOutput\"E\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14*\x12/topics/{topic_id}\x12\x9b\x01\n\x0bUpdateTopic\x12!.eolymp.taxonomy.UpdateTopicInput\x1a\".eolymp.taxonomy.UpdateTopicOutput\"E\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14\x1a\x12/topics/{topic_id}\x12\xa0\x01\n\rDescribeTopic\x12#.eolymp.taxonomy.DescribeTopicInput\x1a$.eolymp.taxonomy.DescribeTopicOutput\"D\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/topics/{topic_id}\x12\x8c\x01\n\nListTopics\x12 .eolymp.taxonomy.ListTopicsInput\x1a!.eolymp.taxonomy.ListTopicsOutput\"9\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/topics\x12\xba\x01\n\x0eTranslateTopic\x12$.eolymp.taxonomy.TranslateTopicInput\x1a%.eolymp.taxonomy.TranslateTopicOutput\"[\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02*\x1a(/topics/{topic_id}/translations/{locale}\x12\xc3\x01\n\x11\x44\x65leteTranslation\x12\'.eolymp.taxonomy.DeleteTranslationInput\x1a(.eolymp.taxonomy.DeleteTranslationOutput\"[\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02**(/topics/{topic_id}/translations/{locale}\x12\xb6\x01\n\x10ListTranslations\x12&.eolymp.taxonomy.ListTranslationsInput\x1a\'.eolymp.taxonomy.ListTranslationsOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!*\x1f/topics/{topic_id}/translationsB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.topic_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _TOPICSERVICE.methods_by_name['CreateTopic']._options = None
  _TOPICSERVICE.methods_by_name['CreateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\t\"\007/topics'
  _TOPICSERVICE.methods_by_name['DeleteTopic']._options = None
  _TOPICSERVICE.methods_by_name['DeleteTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\024*\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['UpdateTopic']._options = None
  _TOPICSERVICE.methods_by_name['UpdateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\024\032\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['DescribeTopic']._options = None
  _TOPICSERVICE.methods_by_name['DescribeTopic']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\022\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['ListTopics']._options = None
  _TOPICSERVICE.methods_by_name['ListTopics']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/topics'
  _TOPICSERVICE.methods_by_name['TranslateTopic']._options = None
  _TOPICSERVICE.methods_by_name['TranslateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002*\032(/topics/{topic_id}/translations/{locale}'
  _TOPICSERVICE.methods_by_name['DeleteTranslation']._options = None
  _TOPICSERVICE.methods_by_name['DeleteTranslation']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002**(/topics/{topic_id}/translations/{locale}'
  _TOPICSERVICE.methods_by_name['ListTranslations']._options = None
  _TOPICSERVICE.methods_by_name['ListTranslations']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002!*\037/topics/{topic_id}/translations'
  _CREATETOPICINPUT._serialized_start=219
  _CREATETOPICINPUT._serialized_end=276
  _CREATETOPICOUTPUT._serialized_start=278
  _CREATETOPICOUTPUT._serialized_end=315
  _DELETETOPICINPUT._serialized_start=317
  _DELETETOPICINPUT._serialized_end=353
  _DELETETOPICOUTPUT._serialized_start=355
  _DELETETOPICOUTPUT._serialized_end=374
  _UPDATETOPICINPUT._serialized_start=377
  _UPDATETOPICINPUT._serialized_end=563
  _UPDATETOPICINPUT_PATCH._serialized_start=510
  _UPDATETOPICINPUT_PATCH._serialized_end=563
  _UPDATETOPICOUTPUT._serialized_start=565
  _UPDATETOPICOUTPUT._serialized_end=584
  _DESCRIBETOPICINPUT._serialized_start=586
  _DESCRIBETOPICINPUT._serialized_end=640
  _DESCRIBETOPICOUTPUT._serialized_start=642
  _DESCRIBETOPICOUTPUT._serialized_end=702
  _LISTTOPICSINPUT._serialized_start=705
  _LISTTOPICSINPUT._serialized_end=945
  _LISTTOPICSINPUT_FILTER._serialized_start=828
  _LISTTOPICSINPUT_FILTER._serialized_end=945
  _LISTTOPICSOUTPUT._serialized_start=947
  _LISTTOPICSOUTPUT._serialized_end=1019
  _TRANSLATETOPICINPUT._serialized_start=1021
  _TRANSLATETOPICINPUT._serialized_end=1133
  _TRANSLATETOPICOUTPUT._serialized_start=1135
  _TRANSLATETOPICOUTPUT._serialized_end=1157
  _DELETETRANSLATIONINPUT._serialized_start=1159
  _DELETETRANSLATIONINPUT._serialized_end=1217
  _DELETETRANSLATIONOUTPUT._serialized_start=1219
  _DELETETRANSLATIONOUTPUT._serialized_end=1244
  _LISTTRANSLATIONSINPUT._serialized_start=1247
  _LISTTRANSLATIONSINPUT._serialized_end=1442
  _LISTTRANSLATIONSINPUT_FILTER._serialized_start=1384
  _LISTTRANSLATIONSINPUT_FILTER._serialized_end=1442
  _LISTTRANSLATIONSOUTPUT._serialized_start=1444
  _LISTTRANSLATIONSOUTPUT._serialized_end=1534
  _TOPICSERVICE._serialized_start=1537
  _TOPICSERVICE._serialized_end=2892
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/announcement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/judge/announcement.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8e\x01\n\x0c\x41nnouncement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\n \x01(\t\x12\x0f\n\x07message\x18\x0b \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.announcement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ANNOUNCEMENT._serialized_start=83
  _ANNOUNCEMENT._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/forum_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import forum_pb2 as eolymp_dot_discussion_dot_forum__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/discussion/forum_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/discussion/forum.proto\x1a!eolymp/wellknown/expression.proto\"6\n\x12\x44\x65scribeForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\">\n\x13\x44\x65scribeForumOutput\x12\'\n\x05\x66orum\x18\x01 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"\xf3\x01\n\x0fListForumsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.discussion.ListForumsInput.Filter\x1av\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tparent_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"J\n\x10ListForumsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.discussion.Forum\";\n\x10\x43reateForumInput\x12\'\n\x05\x66orum\x18\x01 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"%\n\x11\x43reateForumOutput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\"M\n\x10UpdateForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\x12\'\n\x05\x66orum\x18\x02 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"\x13\n\x11UpdateForumOutput\"$\n\x10\x44\x65leteForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteForumOutput2\xae\x06\n\x0c\x46orumService\x12\xa7\x01\n\rDescribeForum\x12%.eolymp.discussion.DescribeForumInput\x1a&.eolymp.discussion.DescribeForumOutput\"G\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:forum:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x14\x12\x12/forums/{forum_id}\x12\x92\x01\n\nListForums\x12\".eolymp.discussion.ListForumsInput\x1a#.eolymp.discussion.ListForumsOutput\";\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:forum:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/forums\x12\x96\x01\n\x0b\x43reateForum\x12#.eolymp.discussion.CreateForumInput\x1a$.eolymp.discussion.CreateForumOutput\"<\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\t\"\x07/forums\x12\xa1\x01\n\x0bUpdateForum\x12#.eolymp.discussion.UpdateForumInput\x1a$.eolymp.discussion.UpdateForumOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x14\x1a\x12/forums/{forum_id}\x12\xa1\x01\n\x0b\x44\x65leteForum\x12#.eolymp.discussion.DeleteForumInput\x1a$.eolymp.discussion.DeleteForumOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x14*\x12/forums/{forum_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.forum_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _FORUMSERVICE.methods_by_name['DescribeForum']._options = None
  _FORUMSERVICE.methods_by_name['DescribeForum']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:forum:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\024\022\022/forums/{forum_id}'
  _FORUMSERVICE.methods_by_name['ListForums']._options = None
  _FORUMSERVICE.methods_by_name['ListForums']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:forum:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/forums'
  _FORUMSERVICE.methods_by_name['CreateForum']._options = None
  _FORUMSERVICE.methods_by_name['CreateForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\t\"\007/forums'
  _FORUMSERVICE.methods_by_name['UpdateForum']._options = None
  _FORUMSERVICE.methods_by_name['UpdateForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\024\032\022/forums/{forum_id}'
  _FORUMSERVICE.methods_by_name['DeleteForum']._options = None
  _FORUMSERVICE.methods_by_name['DeleteForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\024*\022/forums/{forum_id}'
  _DESCRIBEFORUMINPUT._serialized_start=225
  _DESCRIBEFORUMINPUT._serialized_end=279
  _DESCRIBEFORUMOUTPUT._serialized_start=281
  _DESCRIBEFORUMOUTPUT._serialized_end=343
  _LISTFORUMSINPUT._serialized_start=346
  _LISTFORUMSINPUT._serialized_end=589
  _LISTFORUMSINPUT_FILTER._serialized_start=471
  _LISTFORUMSINPUT_FILTER._serialized_end=589
  _LISTFORUMSOUTPUT._serialized_start=591
  _LISTFORUMSOUTPUT._serialized_end=665
  _CREATEFORUMINPUT._serialized_start=667
  _CREATEFORUMINPUT._serialized_end=726
  _CREATEFORUMOUTPUT._serialized_start=728
  _CREATEFORUMOUTPUT._serialized_end=765
  _UPDATEFORUMINPUT._serialized_start=767
  _UPDATEFORUMINPUT._serialized_end=844
  _UPDATEFORUMOUTPUT._serialized_start=846
  _UPDATEFORUMOUTPUT._serialized_end=865
  _DELETEFORUMINPUT._serialized_start=867
  _DELETEFORUMINPUT._serialized_end=903
  _DELETEFORUMOUTPUT._serialized_start=905
  _DELETEFORUMOUTPUT._serialized_end=924
  _FORUMSERVICE._serialized_start=927
  _FORUMSERVICE._serialized_end=1741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import testing_config_pb2 as eolymp_dot_atlas_dot_testing__config__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.atlas import testing_testset_pb2 as eolymp_dot_atlas_dot_testing__testset__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/atlas/testing_config.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\"eolymp/atlas/testing_testset.proto\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\"[\n\x18UpdateTestingConfigInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x1b\n\x19UpdateTestingConfigOutput\"A\n\x1a\x44\x65scribeTestingConfigInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"J\n\x1b\x44\x65scribeTestingConfigOutput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"V\n\x13UpdateVerifierInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x08verifier\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\"\x16\n\x14UpdateVerifierOutput\"<\n\x15\x44\x65scribeVerifierInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"E\n\x16\x44\x65scribeVerifierOutput\x12+\n\x08verifier\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Verifier\"\\\n\x15UpdateInteractorInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12/\n\ninteractor\x18\x02 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\"\x18\n\x16UpdateInteractorOutput\">\n\x17\x44\x65scribeInteractorInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"K\n\x18\x44\x65scribeInteractorOutput\x12/\n\ninteractor\x18\x01 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\"8\n\x11ListTestsetsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"I\n\x12ListTestsetsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Testset\"O\n\x14\x44\x65scribeTestsetInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeTestsetOutput\x12&\n\x07testset\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"P\n\x12\x43reateTestsetInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"!\n\x13\x43reateTestsetOutput\x12\n\n\x02id\x18\x01 \x01(\t\"d\n\x12UpdateTestsetInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12&\n\x07testset\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"\x15\n\x13UpdateTestsetOutput\"<\n\x12\x44\x65leteTestsetInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteTestsetOutput\"8\n\x11ListExamplesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"I\n\x0eListTestsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x0fListTestsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"]\n\x11\x44\x65scribeTestInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"6\n\x12\x44\x65scribeTestOutput\x12 \n\x04test\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\"[\n\x0f\x43reateTestInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12 \n\x04test\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"#\n\x10\x43reateTestOutput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"l\n\x0fUpdateTestInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12 \n\x04test\x18\x04 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x12\n\x10UpdateTestOutput\"J\n\x0f\x44\x65leteTestInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\"\x12\n\x10\x44\x65leteTestOutput2\xae\x15\n\x0eTestingService\x12\xa2\x01\n\x13UpdateTestingConfig\x12&.eolymp.atlas.UpdateTestingConfigInput\x1a\'.eolymp.atlas.UpdateTestingConfigOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/testing\x12\xa8\x01\n\x15\x44\x65scribeTestingConfig\x12(.eolymp.atlas.DescribeTestingConfigInput\x1a).eolymp.atlas.DescribeTestingConfigOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\n\x12\x08/testing\x12\x93\x01\n\rUpdateChecker\x12!.eolymp.atlas.UpdateVerifierInput\x1a\".eolymp.atlas.UpdateVerifierOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\x1a\t/verifier\x12\x99\x01\n\x0f\x44\x65scribeChecker\x12#.eolymp.atlas.DescribeVerifierInput\x1a$.eolymp.atlas.DescribeVerifierOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/verifier\x12\x9c\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\r\x1a\x0b/interactor\x12\xa2\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\r\x12\x0b/interactor\x12\x91\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0b\"\t/testsets\x12\x9e\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x1a\x16/testsets/{testset_id}\x12\x9e\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18*\x16/testsets/{testset_id}\x12\xa4\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/testsets/{testset_id}\x12\x8e\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0b\x12\t/testsets\x12\x9c\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1e\"\x1c/testsets/{testset_id}/tests\x12\xa6\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02(\x1a&/testsets/{testset_id}/tests/{test_id}\x12\xa6\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02(*&/testsets/{testset_id}/tests/{test_id}\x12\xab\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02(\x12&/testsets/{testset_id}/tests/{test_id}\x12\x98\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1e\x12\x1c/testsets/{testset_id}/tests\x12\x8d\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/examplesB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _TESTINGSERVICE.methods_by_name['UpdateTestingConfig']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\n\032\010/testing'
  _TESTINGSERVICE.methods_by_name['DescribeTestingConfig']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\n\022\010/testing'
  _TESTINGSERVICE.methods_by_name['UpdateChecker']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateChecker']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\013\032\t/verifier'
  _TESTINGSERVICE.methods_by_name['DescribeChecker']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeChecker']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\013\022\t/verifier'
  _TESTINGSERVICE.methods_by_name['UpdateInteractor']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\r\032\013/interactor'
  _TESTINGSERVICE.methods_by_name['DescribeInteractor']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\r\022\013/interactor'
  _TESTINGSERVICE.methods_by_name['CreateTestset']._options = None
  _TESTINGSERVICE.methods_by_name['CreateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\013\"\t/testsets'
  _TESTINGSERVICE.methods_by_name['UpdateTestset']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030\032\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['DeleteTestset']._options = None
  _TESTINGSERVICE.methods_by_name['DeleteTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030*\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['DescribeTestset']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['ListTestsets']._options = None
  _TESTINGSERVICE.methods_by_name['ListTestsets']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\013\022\t/testsets'
  _TESTINGSERVICE.methods_by_name['CreateTest']._options = None
  _TESTINGSERVICE.methods_by_name['CreateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002\036\"\034/testsets/{testset_id}/tests'
  _TESTINGSERVICE.methods_by_name['UpdateTest']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002(\032&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['DeleteTest']._options = None
  _TESTINGSERVICE.methods_by_name['DeleteTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002(*&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['DescribeTest']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002(\022&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['ListTests']._options = None
  _TESTINGSERVICE.methods_by_name['ListTests']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\036\022\034/testsets/{testset_id}/tests'
  _TESTINGSERVICE.methods_by_name['ListExamples']._options = None
  _TESTINGSERVICE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/examples'
  _UPDATETESTINGCONFIGINPUT._serialized_start=321
  _UPDATETESTINGCONFIGINPUT._serialized_end=412
  _UPDATETESTINGCONFIGOUTPUT._serialized_start=414
  _UPDATETESTINGCONFIGOUTPUT._serialized_end=441
  _DESCRIBETESTINGCONFIGINPUT._serialized_start=443
  _DESCRIBETESTINGCONFIGINPUT._serialized_end=508
  _DESCRIBETESTINGCONFIGOUTPUT._serialized_start=510
  _DESCRIBETESTINGCONFIGOUTPUT._serialized_end=584
  _UPDATEVERIFIERINPUT._serialized_start=586
  _UPDATEVERIFIERINPUT._serialized_end=672
  _UPDATEVERIFIEROUTPUT._serialized_start=674
  _UPDATEVERIFIEROUTPUT._serialized_end=696
  _DESCRIBEVERIFIERINPUT._serialized_start=698
  _DESCRIBEVERIFIERINPUT._serialized_end=758
  _DESCRIBEVERIFIEROUTPUT._serialized_start=760
  _DESCRIBEVERIFIEROUTPUT._serialized_end=829
  _UPDATEINTERACTORINPUT._serialized_start=831
  _UPDATEINTERACTORINPUT._serialized_end=923
  _UPDATEINTERACTOROUTPUT._serialized_start=925
  _UPDATEINTERACTOROUTPUT._serialized_end=949
  _DESCRIBEINTERACTORINPUT._serialized_start=951
  _DESCRIBEINTERACTORINPUT._serialized_end=1013
  _DESCRIBEINTERACTOROUTPUT._serialized_start=1015
  _DESCRIBEINTERACTOROUTPUT._serialized_end=1090
  _LISTTESTSETSINPUT._serialized_start=1092
  _LISTTESTSETSINPUT._serialized_end=1148
  _LISTTESTSETSOUTPUT._serialized_start=1150
  _LISTTESTSETSOUTPUT._serialized_end=1223
  _DESCRIBETESTSETINPUT._serialized_start=1225
  _DESCRIBETESTSETINPUT._serialized_end=1304
  _DESCRIBETESTSETOUTPUT._serialized_start=1306
  _DESCRIBETESTSETOUTPUT._serialized_end=1369
  _CREATETESTSETINPUT._serialized_start=1371
  _CREATETESTSETINPUT._serialized_end=1451
  _CREATETESTSETOUTPUT._serialized_start=1453
  _CREATETESTSETOUTPUT._serialized_end=1486
  _UPDATETESTSETINPUT._serialized_start=1488
  _UPDATETESTSETINPUT._serialized_end=1588
  _UPDATETESTSETOUTPUT._serialized_start=1590
  _UPDATETESTSETOUTPUT._serialized_end=1611
  _DELETETESTSETINPUT._serialized_start=1613
  _DELETETESTSETINPUT._serialized_end=1673
  _DELETETESTSETOUTPUT._serialized_start=1675
  _DELETETESTSETOUTPUT._serialized_end=1696
  _LISTEXAMPLESINPUT._serialized_start=1698
  _LISTEXAMPLESINPUT._serialized_end=1754
  _LISTEXAMPLESOUTPUT._serialized_start=1756
  _LISTEXAMPLESOUTPUT._serialized_end=1814
  _LISTTESTSINPUT._serialized_start=1816
  _LISTTESTSINPUT._serialized_end=1889
  _LISTTESTSOUTPUT._serialized_start=1891
  _LISTTESTSOUTPUT._serialized_end=1958
  _DESCRIBETESTINPUT._serialized_start=1960
  _DESCRIBETESTINPUT._serialized_end=2053
  _DESCRIBETESTOUTPUT._serialized_start=2055
  _DESCRIBETESTOUTPUT._serialized_end=2109
  _CREATETESTINPUT._serialized_start=2111
  _CREATETESTINPUT._serialized_end=2202
  _CREATETESTOUTPUT._serialized_start=2204
  _CREATETESTOUTPUT._serialized_end=2239
  _UPDATETESTINPUT._serialized_start=2241
  _UPDATETESTINPUT._serialized_end=2349
  _UPDATETESTOUTPUT._serialized_start=2351
  _UPDATETESTOUTPUT._serialized_end=2369
  _DELETETESTINPUT._serialized_start=2371
  _DELETETESTINPUT._serialized_end=2445
  _DELETETESTOUTPUT._serialized_start=2447
  _DELETETESTOUTPUT._serialized_end=2465
  _TESTINGSERVICE._serialized_start=2468
  _TESTINGSERVICE._serialized_end=5202
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Space(_message.Message):
    __slots__ = ["id", "image", "key", "max_team_size", "membership", "min_team_size", "name", "permissions", "plan", "type", "url", "visibility"]
    class Membership(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Quota(_message.Message):
        __slots__ = ["active_contests_per_space", "attributes_per_space", "contests_per_space", "courses_per_space", "members_per_space", "participants_per_contest", "permissions_per_space", "problems_per_contest", "problems_per_space", "scoreboards_per_space"]
        ACTIVE_CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        COURSES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        MEMBERS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
        PERMISSIONS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
        PROBLEMS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        SCOREBOARDS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        active_contests_per_space: int
        attributes_per_space: int
        contests_per_space: int
        courses_per_space: int
        members_per_space: int
        participants_per_contest: int
        permissions_per_space: int
        problems_per_contest: int
        problems_per_space: int
        scoreboards_per_space: int
        def __init__(self, problems_per_space: _Optional[int] = ..., members_per_space: _Optional[int] = ..., contests_per_space: _Optional[int] = ..., active_contests_per_space: _Optional[int] = ..., scoreboards_per_space: _Optional[int] = ..., permissions_per_space: _Optional[int] = ..., attributes_per_space: _Optional[int] = ..., courses_per_space: _Optional[int] = ..., problems_per_contest: _Optional[int] = ..., participants_per_contest: _Optional[int] = ...) -> None: ...
    CLASSROOM: Space.Type
    COMPETITION: Space.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    INDIVIDUAL: Space.Membership
    KEY_FIELD_NUMBER: _ClassVar[int]
    MAX_TEAM_SIZE_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIP_FIELD_NUMBER: _ClassVar[int]
    MIN_TEAM_SIZE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OTHER: Space.Type
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    PRIVATE: Space.Visibility
    PUBLIC: Space.Visibility
    TEAM: Space.Membership
    TEAMROOM: Space.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_MEMBERSHIP: Space.Membership
    UNKNOWN_TYPE: Space.Type
    UNKNOWN_VISIBILITY: Space.Visibility
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    id: str
    image: str
    key: str
    max_team_size: int
    membership: Space.Membership
    min_team_size: int
    name: str
    permissions: _containers.RepeatedScalarFieldContainer[str]
    plan: str
    type: Space.Type
    url: str
    visibility: Space.Visibility
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., image: _Optional[str] = ..., type: _Optional[_Union[Space.Type, str]] = ..., plan: _Optional[str] = ..., visibility: _Optional[_Union[Space.Visibility, str]] = ..., membership: _Optional[_Union[Space.Membership, str]] = ..., min_team_size: _Optional[int] = ..., max_team_size: _Optional[int] = ..., permissions: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/harmony/consent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/harmony/consent.proto\x12\x0e\x65olymp.harmony\x1a\x1fgoogle/protobuf/timestamp.proto\"\xde\x01\n\x07\x43onsent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x61greement_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\trevocable\x18\x04 \x01(\x08\x12.\n\x06status\x18\n \x01(\x0e\x32\x1e.eolymp.harmony.Consent.Status\x12*\n\x06set_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/harmony;harmonyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.harmony.consent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/harmony;harmony'
  _CONSENT._serialized_start=82
  _CONSENT._serialized_end=304
  _CONSENT_STATUS._serialized_start=255
  _CONSENT_STATUS._serialized_end=304
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class File(_message.Message):
    __slots__ = ["path", "source_ern", "source_url"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    path: str
    source_ern: str
    source_url: str
    def __init__(self, path: _Optional[str] = ..., source_ern: _Optional[str] = ..., source_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/atlas.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import attachment_service_pb2 as eolymp_dot_atlas_dot_attachment__service__pb2
from eolymp.atlas import bookmark_service_pb2 as eolymp_dot_atlas_dot_bookmark__service__pb2
from eolymp.atlas import code_template_service_pb2 as eolymp_dot_atlas_dot_code__template__service__pb2
from eolymp.atlas import library_service_pb2 as eolymp_dot_atlas_dot_library__service__pb2
from eolymp.atlas import problem_service_pb2 as eolymp_dot_atlas_dot_problem__service__pb2
from eolymp.atlas import scoring_service_pb2 as eolymp_dot_atlas_dot_scoring__service__pb2
from eolymp.atlas import statement_service_pb2 as eolymp_dot_atlas_dot_statement__service__pb2
from eolymp.atlas import submission_service_pb2 as eolymp_dot_atlas_dot_submission__service__pb2
from eolymp.atlas import testing_service_pb2 as eolymp_dot_atlas_dot_testing__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/atlas/atlas.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a%eolymp/atlas/attachment_service.proto\x1a#eolymp/atlas/bookmark_service.proto\x1a(eolymp/atlas/code_template_service.proto\x1a\"eolymp/atlas/library_service.proto\x1a\"eolymp/atlas/problem_service.proto\x1a\"eolymp/atlas/scoring_service.proto\x1a$eolymp/atlas/statement_service.proto\x1a%eolymp/atlas/submission_service.proto\x1a\"eolymp/atlas/testing_service.proto2\xed\x46\n\x05\x41tlas\x12\x91\x01\n\rCreateProblem\x12 .eolymp.atlas.CreateProblemInput\x1a!.eolymp.atlas.CreateProblemOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\"\t/problems\x12\x9e\x01\n\rDeleteProblem\x12 .eolymp.atlas.DeleteProblemInput\x1a!.eolymp.atlas.DeleteProblemOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/problems/{problem_id}\x12\x8d\x01\n\x0cListProblems\x12\x1f.eolymp.atlas.ListProblemsInput\x1a .eolymp.atlas.ListProblemsOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/problems\x12\xa3\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.atlas.DescribeProblemInput\x1a#.eolymp.atlas.DescribeProblemOutput\"G\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x12\x16/problems/{problem_id}\x12\x9e\x01\n\rUpdateProblem\x12 .eolymp.atlas.UpdateProblemInput\x1a!.eolymp.atlas.UpdateProblemOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x1a\x16/problems/{problem_id}\x12\x9d\x01\n\x0bSyncProblem\x12\x1e.eolymp.atlas.SyncProblemInput\x1a\x1f.eolymp.atlas.SyncProblemOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/problems/{problem_id}/sync\x12\x86\x01\n\x0bSetBookmark\x12\x1e.eolymp.atlas.SetBookmarkInput\x1a\x1f.eolymp.atlas.SetBookmarkOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02!\"\x1f/problems/{problem_id}/bookmark\x12\x86\x01\n\x0bGetBookmark\x12\x1e.eolymp.atlas.GetBookmarkInput\x1a\x1f.eolymp.atlas.GetBookmarkOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/bookmark\x12\xa3\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\"P\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/examples\x12\xb8\x01\n\x13UpdateTestingConfig\x12&.eolymp.atlas.UpdateTestingConfigInput\x1a\'.eolymp.atlas.UpdateTestingConfigOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \x1a\x1e/problems/{problem_id}/testing\x12\xbe\x01\n\x15\x44\x65scribeTestingConfig\x12(.eolymp.atlas.DescribeTestingConfigInput\x1a).eolymp.atlas.DescribeTestingConfigOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \x12\x1e/problems/{problem_id}/testing\x12\xaa\x01\n\x0eUpdateVerifier\x12!.eolymp.atlas.UpdateVerifierInput\x1a\".eolymp.atlas.UpdateVerifierOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\x1a\x1f/problems/{problem_id}/verifier\x12\xb0\x01\n\x10\x44\x65scribeVerifier\x12#.eolymp.atlas.DescribeVerifierInput\x1a$.eolymp.atlas.DescribeVerifierOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/verifier\x12\xb2\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\x1a!/problems/{problem_id}/interactor\x12\xb8\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#\x12!/problems/{problem_id}/interactor\x12\xaf\x01\n\x0f\x43reateStatement\x12\".eolymp.atlas.CreateStatementInput\x1a#.eolymp.atlas.CreateStatementOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\x1a!/problems/{problem_id}/statements\x12\xbe\x01\n\x0fUpdateStatement\x12\".eolymp.atlas.UpdateStatementInput\x1a#.eolymp.atlas.UpdateStatementOutput\"b\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32\x1a\x30/problems/{problem_id}/statements/{statement_id}\x12\xbe\x01\n\x0f\x44\x65leteStatement\x12\".eolymp.atlas.DeleteStatementInput\x1a#.eolymp.atlas.DeleteStatementOutput\"b\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32*0/problems/{problem_id}/statements/{statement_id}\x12\xab\x01\n\x0eListStatements\x12!.eolymp.atlas.ListStatementsInput\x1a\".eolymp.atlas.ListStatementsOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/problems/{problem_id}/statements\x12\xc3\x01\n\x11\x44\x65scribeStatement\x12$.eolymp.atlas.DescribeStatementInput\x1a%.eolymp.atlas.DescribeStatementOutput\"a\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x32\x12\x30/problems/{problem_id}/statements/{statement_id}\x12\xad\x01\n\x0fLookupStatement\x12\".eolymp.atlas.LookupStatementInput\x1a#.eolymp.atlas.LookupStatementOutput\"Q\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\"\x12 /problems/{problem_id}/translate\x12\xae\x01\n\x10PreviewStatement\x12#.eolymp.atlas.PreviewStatementInput\x1a$.eolymp.atlas.PreviewStatementOutput\"O\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02 \"\x1e/problems/{problem_id}/renders\x12\xa7\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02!\"\x1f/problems/{problem_id}/testsets\x12\xb4\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\x1a,/problems/{problem_id}/testsets/{testset_id}\x12\xb4\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02.*,/problems/{problem_id}/testsets/{testset_id}\x12\xa4\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/testsets\x12\xba\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\x12,/problems/{problem_id}/testsets/{testset_id}\x12\xb2\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"e\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x34\"2/problems/{problem_id}/testsets/{testset_id}/tests\x12\xbc\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02>\x1a</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}\x12\xbc\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02>*</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}\x12\xae\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"d\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x34\x12\x32/problems/{problem_id}/testsets/{testset_id}/tests\x12\xc1\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02>\x12</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}\x12\xb7\x01\n\x12\x43reateCodeTemplate\x12%.eolymp.atlas.CreateCodeTemplateInput\x1a&.eolymp.atlas.CreateCodeTemplateOutput\"R\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\"\" /problems/{problem_id}/templates\x12\xc5\x01\n\x12UpdateCodeTemplate\x12%.eolymp.atlas.UpdateCodeTemplateInput\x1a&.eolymp.atlas.UpdateCodeTemplateOutput\"`\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x30\"./problems/{problem_id}/templates/{template_id}\x12\xc5\x01\n\x12\x44\x65leteCodeTemplate\x12%.eolymp.atlas.DeleteCodeTemplateInput\x1a&.eolymp.atlas.DeleteCodeTemplateOutput\"`\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x30*./problems/{problem_id}/templates/{template_id}\x12\xb3\x01\n\x11ListCodeTemplates\x12$.eolymp.atlas.ListCodeTemplatesInput\x1a%.eolymp.atlas.ListCodeTemplatesOutput\"Q\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\"\x12 /problems/{problem_id}/templates\x12\xca\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.atlas.DescribeCodeTemplateInput\x1a(.eolymp.atlas.DescribeCodeTemplateOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x30\x12./problems/{problem_id}/templates/{template_id}\x12\xb5\x01\n\x12LookupCodeTemplate\x12%.eolymp.atlas.LookupCodeTemplateInput\x1a&.eolymp.atlas.LookupCodeTemplateOutput\"P\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/template\x12\xb3\x01\n\x10\x43reateAttachment\x12#.eolymp.atlas.CreateAttachmentInput\x1a$.eolymp.atlas.CreateAttachmentOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\"/problems/{problem_id}/attachments\x12\xc3\x01\n\x10UpdateAttachment\x12#.eolymp.atlas.UpdateAttachmentInput\x1a$.eolymp.atlas.UpdateAttachmentOutput\"d\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x34\"2/problems/{problem_id}/attachments/{attachment_id}\x12\xc3\x01\n\x10\x44\x65leteAttachment\x12#.eolymp.atlas.DeleteAttachmentInput\x1a$.eolymp.atlas.DeleteAttachmentOutput\"d\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x34*2/problems/{problem_id}/attachments/{attachment_id}\x12\xaf\x01\n\x0fListAttachments\x12\".eolymp.atlas.ListAttachmentsInput\x1a#.eolymp.atlas.ListAttachmentsOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02$\x12\"/problems/{problem_id}/attachments\x12\xc8\x01\n\x12\x44\x65scribeAttachment\x12%.eolymp.atlas.DescribeAttachmentInput\x1a&.eolymp.atlas.DescribeAttachmentOutput\"c\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x34\x12\x32/problems/{problem_id}/attachments/{attachment_id}\x12\x95\x01\n\x0cListVersions\x12\x1f.eolymp.atlas.ListVersionsInput\x1a .eolymp.atlas.ListVersionsOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/versions\x12\x95\x01\n\x0eListProblemTop\x12!.eolymp.atlas.ListProblemTopInput\x1a\".eolymp.atlas.ListProblemTopOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/problems/{problem_id}/top\x12\xb1\x01\n\x16\x44\x65scribeProblemGrading\x12).eolymp.atlas.DescribeProblemGradingInput\x1a*.eolymp.atlas.DescribeProblemGradingOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02 \x12\x1e/problems/{problem_id}/grading\x12\xa7\x01\n\x10\x43reateSubmission\x12#.eolymp.atlas.CreateSubmissionInput\x1a$.eolymp.atlas.CreateSubmissionOutput\"H\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02$\"\"/problems/{problem_id}/submissions\x12\xbc\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.atlas.DescribeSubmissionInput\x1a&.eolymp.atlas.DescribeSubmissionOutput\"W\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x34\x12\x32/problems/{problem_id}/submissions/{submission_id}\x12\xbe\x01\n\x10RetestSubmission\x12#.eolymp.atlas.RetestSubmissionInput\x1a$.eolymp.atlas.RetestSubmissionOutput\"_\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02;\"9/problems/{problem_id}/submissions/{submission_id}/retest\x12\x8d\x01\n\x0fListSubmissions\x12\".eolymp.atlas.ListSubmissionsInput\x1a#.eolymp.atlas.ListSubmissionsOutput\"1\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xa4\x01\n\rDescribeScore\x12 .eolymp.atlas.DescribeScoreInput\x1a!.eolymp.atlas.DescribeScoreOutput\"N\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02+\x12)/problems/{problem_id}/scores/{member_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.atlas_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _ATLAS.methods_by_name['CreateProblem']._options = None
  _ATLAS.methods_by_name['CreateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\013\"\t/problems'
  _ATLAS.methods_by_name['DeleteProblem']._options = None
  _ATLAS.methods_by_name['DeleteProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\030*\026/problems/{problem_id}'
  _ATLAS.methods_by_name['ListProblems']._options = None
  _ATLAS.methods_by_name['ListProblems']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/problems'
  _ATLAS.methods_by_name['DescribeProblem']._options = None
  _ATLAS.methods_by_name['DescribeProblem']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\030\022\026/problems/{problem_id}'
  _ATLAS.methods_by_name['UpdateProblem']._options = None
  _ATLAS.methods_by_name['UpdateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\030\032\026/problems/{problem_id}'
  _ATLAS.methods_by_name['SyncProblem']._options = None
  _ATLAS.methods_by_name['SyncProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\035\"\033/problems/{problem_id}/sync'
  _ATLAS.methods_by_name['SetBookmark']._options = None
  _ATLAS.methods_by_name['SetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002!\"\037/problems/{problem_id}/bookmark'
  _ATLAS.methods_by_name['GetBookmark']._options = None
  _ATLAS.methods_by_name['GetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\310A\370\342\nd\202\323\344\223\002!\022\037/problems/{problem_id}/bookmark'
  _ATLAS.methods_by_name['ListExamples']._options = None
  _ATLAS.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002!\022\037/problems/{problem_id}/examples'
  _ATLAS.methods_by_name['UpdateTestingConfig']._options = None
  _ATLAS.methods_by_name['UpdateTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002 \032\036/problems/{problem_id}/testing'
  _ATLAS.methods_by_name['DescribeTestingConfig']._options = None
  _ATLAS.methods_by_name['DescribeTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002 \022\036/problems/{problem_id}/testing'
  _ATLAS.methods_by_name['UpdateVerifier']._options = None
  _ATLAS.methods_by_name['UpdateVerifier']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002!\032\037/problems/{problem_id}/verifier'
  _ATLAS.methods_by_name['DescribeVerifier']._options = None
  _ATLAS.methods_by_name['DescribeVerifier']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002!\022\037/problems/{problem_id}/verifier'
  _ATLAS.methods_by_name['UpdateInteractor']._options = None
  _ATLAS.methods_by_name['UpdateInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002#\032!/problems/{problem_id}/interactor'
  _ATLAS.methods_by_name['DescribeInteractor']._options = None
  _ATLAS.methods_by_name['DescribeInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002#\022!/problems/{problem_id}/interactor'
  _ATLAS.methods_by_name['CreateStatement']._options = None
  _ATLAS.methods_by_name['CreateStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\032!/problems/{problem_id}/statements'
  _ATLAS.methods_by_name['UpdateStatement']._options = None
  _ATLAS.methods_by_name['UpdateStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022\0320/problems/{problem_id}/statements/{statement_id}'
  _ATLAS.methods_by_name['DeleteStatement']._options = None
  _ATLAS.methods_by_name['DeleteStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022*0/problems/{problem_id}/statements/{statement_id}'
  _ATLAS.methods_by_name['ListStatements']._options = None
  _ATLAS.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002#\022!/problems/{problem_id}/statements'
  _ATLAS.methods_by_name['DescribeStatement']._options = None
  _ATLAS.methods_by_name['DescribeStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0022\0220/problems/{problem_id}/statements/{statement_id}'
  _ATLAS.methods_by_name['LookupStatement']._options = None
  _ATLAS.methods_by_name['LookupStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\"\022 /problems/{problem_id}/translate'
  _ATLAS.methods_by_name['PreviewStatement']._options = None
  _ATLAS.methods_by_name['PreviewStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002 \"\036/problems/{problem_id}/renders'
  _ATLAS.methods_by_name['CreateTestset']._options = None
  _ATLAS.methods_by_name['CreateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002!\"\037/problems/{problem_id}/testsets'
  _ATLAS.methods_by_name['UpdateTestset']._options = None
  _ATLAS.methods_by_name['UpdateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002.\032,/problems/{problem_id}/testsets/{testset_id}'
  _ATLAS.methods_by_name['DeleteTestset']._options = None
  _ATLAS.methods_by_name['DeleteTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002.*,/problems/{problem_id}/testsets/{testset_id}'
  _ATLAS.methods_by_name['ListTestsets']._options = None
  _ATLAS.methods_by_name['ListTestsets']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002!\022\037/problems/{problem_id}/testsets'
  _ATLAS.methods_by_name['DescribeTestset']._options = None
  _ATLAS.methods_by_name['DescribeTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002.\022,/problems/{problem_id}/testsets/{testset_id}'
  _ATLAS.methods_by_name['CreateTest']._options = None
  _ATLAS.methods_by_name['CreateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\0024\"2/problems/{problem_id}/testsets/{testset_id}/tests'
  _ATLAS.methods_by_name['UpdateTest']._options = None
  _ATLAS.methods_by_name['UpdateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002>\032</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}'
  _ATLAS.methods_by_name['DeleteTest']._options = None
  _ATLAS.methods_by_name['DeleteTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002>*</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}'
  _ATLAS.methods_by_name['ListTests']._options = None
  _ATLAS.methods_by_name['ListTests']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\0024\0222/problems/{problem_id}/testsets/{testset_id}/tests'
  _ATLAS.methods_by_name['DescribeTest']._options = None
  _ATLAS.methods_by_name['DescribeTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002>\022</problems/{problem_id}/testsets/{testset_id}/tests/{test_id}'
  _ATLAS.methods_by_name['CreateCodeTemplate']._options = None
  _ATLAS.methods_by_name['CreateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\"\" /problems/{problem_id}/templates'
  _ATLAS.methods_by_name['UpdateCodeTemplate']._options = None
  _ATLAS.methods_by_name['UpdateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0020\"./problems/{problem_id}/templates/{template_id}'
  _ATLAS.methods_by_name['DeleteCodeTemplate']._options = None
  _ATLAS.methods_by_name['DeleteCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0020*./problems/{problem_id}/templates/{template_id}'
  _ATLAS.methods_by_name['ListCodeTemplates']._options = None
  _ATLAS.methods_by_name['ListCodeTemplates']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\"\022 /problems/{problem_id}/templates'
  _ATLAS.methods_by_name['DescribeCodeTemplate']._options = None
  _ATLAS.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0020\022./problems/{problem_id}/templates/{template_id}'
  _ATLAS.methods_by_name['LookupCodeTemplate']._options = None
  _ATLAS.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002!\022\037/problems/{problem_id}/template'
  _ATLAS.methods_by_name['CreateAttachment']._options = None
  _ATLAS.methods_by_name['CreateAttachment']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002$\"\"/problems/{problem_id}/attachments'
  _ATLAS.methods_by_name['UpdateAttachment']._options = None
  _ATLAS.methods_by_name['UpdateAttachment']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0024\"2/problems/{problem_id}/attachments/{attachment_id}'
  _ATLAS.methods_by_name['DeleteAttachment']._options = None
  _ATLAS.methods_by_name['DeleteAttachment']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0024*2/problems/{problem_id}/attachments/{attachment_id}'
  _ATLAS.methods_by_name['ListAttachments']._options = None
  _ATLAS.methods_by_name['ListAttachments']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002$\022\"/problems/{problem_id}/attachments'
  _ATLAS.methods_by_name['DescribeAttachment']._options = None
  _ATLAS.methods_by_name['DescribeAttachment']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0024\0222/problems/{problem_id}/attachments/{attachment_id}'
  _ATLAS.methods_by_name['ListVersions']._options = None
  _ATLAS.methods_by_name['ListVersions']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002!\022\037/problems/{problem_id}/versions'
  _ATLAS.methods_by_name['ListProblemTop']._options = None
  _ATLAS.methods_by_name['ListProblemTop']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\034\022\032/problems/{problem_id}/top'
  _ATLAS.methods_by_name['DescribeProblemGrading']._options = None
  _ATLAS.methods_by_name['DescribeProblemGrading']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002 \022\036/problems/{problem_id}/grading'
  _ATLAS.methods_by_name['CreateSubmission']._options = None
  _ATLAS.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002$\"\"/problems/{problem_id}/submissions'
  _ATLAS.methods_by_name['DescribeSubmission']._options = None
  _ATLAS.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\0024\0222/problems/{problem_id}/submissions/{submission_id}'
  _ATLAS.methods_by_name['RetestSubmission']._options = None
  _ATLAS.methods_by_name['RetestSubmission']._serialized_options = b'\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002;\"9/problems/{problem_id}/submissions/{submission_id}/retest'
  _ATLAS.methods_by_name['ListSubmissions']._options = None
  _ATLAS.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\016\022\014/submissions'
  _ATLAS.methods_by_name['DescribeScore']._options = None
  _ATLAS.methods_by_name['DescribeScore']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002+\022)/problems/{problem_id}/scores/{member_id}'
  _ATLAS._serialized_start=481
  _ATLAS._serialized_end=9550
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/events.proto\x12\x0c\x65olymp.judge\x1a\x1e\x65olymp/judge/participant.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x18\x65olymp/judge/score.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\"H\n\x18SubmissionCompletedEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"<\n\x11RebuildScoreEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\t\"\x7f\n\x11ScoreUpdatedEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x1a\n\x12out_of_competition\x18\x04 \x01(\x08\x12\"\n\x05score\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Score\":\n\x12TicketCreatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"^\n\x12TicketUpdatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\"I\n\x17ParticipantCreatedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x17ParticipantUpdatedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x17ParticipantDeletedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.ParticipantB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _SUBMISSIONCOMPLETEDEVENT._serialized_start=185
  _SUBMISSIONCOMPLETEDEVENT._serialized_end=257
  _REBUILDSCOREEVENT._serialized_start=259
  _REBUILDSCOREEVENT._serialized_end=319
  _SCOREUPDATEDEVENT._serialized_start=321
  _SCOREUPDATEDEVENT._serialized_end=448
  _TICKETCREATEDEVENT._serialized_start=450
  _TICKETCREATEDEVENT._serialized_end=508
  _TICKETUPDATEDEVENT._serialized_start=510
  _TICKETUPDATEDEVENT._serialized_end=604
  _PARTICIPANTCREATEDEVENT._serialized_start=606
  _PARTICIPANTCREATEDEVENT._serialized_end=679
  _PARTICIPANTUPDATEDEVENT._serialized_start=681
  _PARTICIPANTUPDATEDEVENT._serialized_end=754
  _PARTICIPANTDELETEDEVENT._serialized_start=756
  _PARTICIPANTDELETEDEVENT._serialized_end=829
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import forum_pb2 as _forum_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateForumInput(_message.Message):
    __slots__ = ["forum"]
    FORUM_FIELD_NUMBER: _ClassVar[int]
    forum: _forum_pb2.Forum
    def __init__(self, forum: _Optional[_Union[_forum_pb2.Forum, _Mapping]] = ...) -> None: ...

class CreateForumOutput(_message.Message):
    __slots__ = ["forum_id"]
    FORUM_ID_FIELD_NUMBER: _ClassVar[int]
    forum_id: str
    def __init__(self, forum_id: _Optional[str] = ...) -> None: ...

class DeleteForumInput(_message.Message):
    __slots__ = ["forum_id"]
    FORUM_ID_FIELD_NUMBER: _ClassVar[int]
    forum_id: str
    def __init__(self, forum_id: _Optional[str] = ...) -> None: ...

class DeleteForumOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeForumInput(_message.Message):
    __slots__ = ["forum_id", "render"]
    FORUM_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    forum_id: str
    render: bool
    def __init__(self, forum_id: _Optional[str] = ..., render: bool = ...) -> None: ...

class DescribeForumOutput(_message.Message):
    __slots__ = ["forum"]
    FORUM_FIELD_NUMBER: _ClassVar[int]
    forum: _forum_pb2.Forum
    def __init__(self, forum: _Optional[_Union[_forum_pb2.Forum, _Mapping]] = ...) -> None: ...

class ListForumsInput(_message.Message):
    __slots__ = ["filters", "offset", "render", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "parent_id", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        PARENT_ID_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        parent_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., parent_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListForumsInput.Filter
    offset: int
    render: bool
    size: int
    def __init__(self, render: bool = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListForumsInput.Filter, _Mapping]] = ...) -> None: ...

class ListForumsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_forum_pb2.Forum]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_forum_pb2.Forum, _Mapping]]] = ...) -> None: ...

class UpdateForumInput(_message.Message):
    __slots__ = ["forum", "forum_id"]
    FORUM_FIELD_NUMBER: _ClassVar[int]
    FORUM_ID_FIELD_NUMBER: _ClassVar[int]
    forum: _forum_pb2.Forum
    forum_id: str
    def __init__(self, forum_id: _Optional[str] = ..., forum: _Optional[_Union[_forum_pb2.Forum, _Mapping]] = ...) -> None: ...

class UpdateForumOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Ghost(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...
